@@ -85,7 +85,7 @@ def isValidScript(scriptpath):
 
 def getRelScriptsFromPath(scriptpaths):
     '''
-    Takes in a list of base paths (eg. ENVI_SCRIPT_PATH list) and recurses the 
+    Takes in a list of base paths (eg. ENVI_SCRIPT_PATH list) and recurses the
     directories looking for valid python files (ie. they don't throw errors
     on import).
 
@@ -322,7 +322,7 @@ class EnviCli(Cmd):
         for line in formatargs(self.basecmds):
             self.vprint(line)
 
-        subsys = self.extsubsys.keys()
+        subsys = list(self.extsubsys.keys())
         subsys.sort()
 
         for sub in subsys:
@@ -376,7 +376,7 @@ class EnviCli(Cmd):
             subnames.sort()
             for subname in subnames:
                 subcfg = self.config.getSubConfig(subname)
-                options = subcfg.keys()
+                options = list(subcfg.keys())
                 options.sort()
                 for optname in options:
                     optval = subcfg.get(optname)
@@ -405,9 +405,9 @@ class EnviCli(Cmd):
             if len(parts) == 2:
                 newval = json.loads(parts[1])
 
-                if type(newval) not in (str,unicode) or type(optval) not in (str,unicode):
+                if (not isinstance(newval, str)) or not isinstance(optval, str):
                     if type(newval) != type(optval):
-                        self.vprint('Invalid Type Mismatch: %r - %r' % (newval,optval))
+                        self.vprint('Invalid Type Mismatch: %r - %r' % (newval, optval))
                         return
 
                 optval = newval
@@ -435,14 +435,14 @@ class EnviCli(Cmd):
 
         self.vprint('')
         self.vprint('Runtime Aliases (not saved):')
-        aliases = self.aliases.keys()
+        aliases = list(self.aliases.keys())
         aliases.sort()
         for alias in aliases:
             self.vprint('%s -> %s' % (alias,self.aliases.get(alias)))
         self.vprint('')
 
         self.vprint('Configured Aliases:')
-        aliases = self.config.cli.aliases.keys()
+        aliases = list(self.config.cli.aliases.keys())
         aliases.sort()
         for alias in aliases:
             self.vprint('%s -> %s' % (alias, self.config.cli.aliases.get(alias)))
@@ -467,7 +467,7 @@ class EnviCli(Cmd):
             code.interact(local=locals)
 
     def parseExpression(self, expr):
-        return long(e_expr.evaluate(expr, self.getExpressionLocals()))
+        return int(e_expr.evaluate(expr, self.getExpressionLocals()))
 
     def do_binstr(self, line):
         '''
@@ -503,7 +503,7 @@ class EnviCli(Cmd):
             sym = self.symobj.getSymByAddr(value, exact=False)
             if sym is not None:
                 self.canvas.addText(" ")
-                self.canvas.addVaText("%s + %d" % (repr(sym),value-long(sym)), value)
+                self.canvas.addVaText("%s + %d" % (repr(sym),value-int(sym)), value)
         else:
             self.canvas.addText("0x%.8x (%d)" % (value, value))
 
@@ -599,7 +599,7 @@ class EnviCli(Cmd):
                 pname = e_mem.reprPerms(perm)
                 totsize += size
                 self.canvas.addVaText("0x%.8x" % addr, addr)
-                sizestr = ("%dK" % (size/1024,)).rjust(8)
+                sizestr = ("%dK" % (size//1024,)).rjust(8)
                 self.canvas.addText("%s\t%s\t%s\n" % (sizestr,pname,fname))
             self.vprint("Total Virtual Memory: %.2f MB" % ((float(totsize)/1024)/1024))
 
@@ -733,7 +733,7 @@ class EnviCli(Cmd):
 
             sym = self.symobj.getSymByAddr(va, exact=False)
             if sym is not None:
-                ret = "%s + 0x%x" % (repr(sym), va-long(sym))
+                ret = "%s + 0x%x" % (repr(sym), va-int(sym))
 
         except Exception:
             ret = hex(va)
