@@ -1,4 +1,3 @@
-import types
 import collections
 
 # Symbol Type Constants ( for serialization )
@@ -18,28 +17,113 @@ class Symbol:
         self.size = size
         self.fname = fname
 
+    def __ge__(self, other):
+        return int(self) >= int(other)
+    def __le__(self, other):
+        return int(self) <= int(other)
+    def __gt__(self, other):
+        return int(self) > int(other)
+    def __lt__(self, other):
+        return int(self) < int(other)
     def __eq__(self, other):
         if not isinstance(other, Symbol):
             return False
-        return long(self) == long(other)
+        return int(self) == int(other)
+    def __add__(self, other):
+        return int(self) + int(other)
+    def __sub__(self, other):
+        return int(self) - int(other)
+    def __mul__(self, other):
+        return int(self) * int(other)
+    def __div__(self, other):
+        return int(self) / int(other)
+    def __floordiv__(self, other):
+        return int(self) // int(other)
+    def __mod__(self, other):
+        return int(self) % int(other)
+    def __divmod__(self, other):
+        return divmod(int(self), int(other))
+    def __pow__(self, other, modulo=None):
+        return pow(int(self), int(other), modulo)
+    def __lshift__(self, other):
+        return int(self) << int(other)
+    def __rshift__(self, other):
+        return int(self) >> int(other)
+    def __and__(self, other):
+        return int(self) & int(other)
+    def __xor__(self, other):
+        return int(self) ^ int(other)
+    def __or__(self, other):
+        return int(self) | int(other)
+    # Operator swapped variants
+    def __radd__(self, other):
+        return int(other) + int(self)
+    def __rsub__(self, other):
+        return int(other) - int(self)
+    def __rmul__(self, other):
+        return int(other) * int(self)
+    def __rdiv__(self, other):
+        return int(other) / int(self)
+    def __rfloordiv__(self, other):
+        return int(other) // int(self)
+    def __rmod__(self, other):
+        return int(other) % int(self)
+    def __rdivmod__(self, other):
+        return divmod(int(other), int(self))
+    def __rpow__(self, other, modulo=None):
+        return pow(int(other), int(self), modulo)
+    def __rlshift__(self, other):
+        return int(other) << int(self)
+    def __rrshift__(self, other):
+        return int(other) >> int(self)
+    def __rand__(self, other):
+        return int(other) & int(self)
+    def __rxor__(self, other):
+        return int(other) ^ int(self)
+    def __ror__(self, other):
+        return int(other) | int(self)
 
-    def __coerce__(self, value):
-        t = type(value)
-
-        if t == types.NoneType:
-            return (True, False)
-
-        if t in (int,long):
-            return (t(self.value), value)
-
-        if isinstance( value, Symbol ):
-            return ( long(self.value), long(value.value) )
+    # Inplace variants
+    def __iadd__(self, other):
+        self.value += int(other)
+        return self
+    def __isub__(self, other):
+        self.value -= int(other)
+        return self
+    def __imul__(self, other):
+        self.value *= int(other)
+        return self
+    def __idiv__(self, other):
+        self.value = int(self.value / int(other))
+        return self
+    def __ifloordiv__(self, other):
+        self.value //= int(other)
+        return self
+    def __imod__(self, other):
+        self.vsSetValue(self % other)
+        self.value %= int(other)
+        return self
+    def __ipow__(self, other, modulo=None):
+        self.value = pow(self.value, other, modulo)
+        return self
+    def __ilshift__(self, other):
+        self.value <<= other
+        return self
+    def __irshift__(self, other):
+        self.value >>= other
+        return self
+    def __iand__(self, other):
+        self.value &= other
+        return self
+    def __ixor__(self, other):
+        self.value ^= other
+        return self
+    def __ior__(self, other):
+        self.value |= other
+        return self
 
     def __hash__(self):
-        return hash(long(self))
-
-    def __long__(self):
-        return long(self.value)
+        return hash(int(self))
 
     def __int__(self):
         return int(self.value)
@@ -106,7 +190,7 @@ class SymbolResolver:
         """
         Delete a symbol from the resolver's namespace
         """
-        symval = long(sym)
+        symval = int(sym)
         self.symaddrs.pop(symval, None)
 
         # bbase = symval & self.bucketmask
@@ -163,7 +247,7 @@ class SymbolResolver:
         # Do we have a symbol tuple?
         symtup = self.symnames.get(name)
         if symtup is not None:
-            return self._symFromTup( symtup )
+            return self._symFromTup(symtup)
 
     def delSymByName(self, name):
         if not self.casesens:
@@ -175,7 +259,7 @@ class SymbolResolver:
 
     def _symFromTup(self, symtup):
         # Create a symbol object and cache it...
-        symaddr,symsize,symname,symtype,symfname = symtup
+        symaddr, symsize, symname, symtype, symfname = symtup
         symclass = symclasses[symtype]
         if symtype == SYMSTOR_SYM_MODULE:
             sym = FileSymbol(symname, symaddr, symsize, width=self.width)
@@ -240,8 +324,7 @@ class SymbolResolver:
         """
         Return a list of the symbols which are contained in this resolver.
         """
-        names = self.symnames.keys()
-        return [ self.getSymByName(name) for name in names ]
+        return [self.getSymByName(name) for name in self.symnames]
 
     def getSymHint(self, va, hidx):
         """
@@ -365,7 +448,4 @@ class FileSymbol(Symbol, SymbolResolver):
     def __nonzero__(self):
         return True
 
-    def __unicode__(self):
-        return Symbol.__str__(self)
-
 symclasses = (Symbol, FunctionSymbol, SectionSymbol, FileSymbol)
