@@ -1,5 +1,6 @@
 import os
 import unittest
+import functools
 
 import vivisect
 
@@ -30,7 +31,7 @@ def getTestPath(*paths):
     return os.path.join(testdir, *paths)
 
 
-# @functools.lrucache() -- python 3 only :(
+@functools.lru_cache()
 def getTestWorkspace(*paths):
     testdir = os.getenv('VIVTESTFILES')
     if not testdir:
