@@ -30,7 +30,7 @@ def getNodeWeightHisto(g):
     weights_to_cb = collections.defaultdict(list)
 
     # create default dict
-    for cb, weight in sorted(nodeweights.items(), lambda x, y: cmp(y[1], x[1])):
+    for cb, weight in sorted(nodeweights.items(), key=lambda x: x[1]):
         if not len(g.getRefsFromByNid(cb)):
             # leaves is a tuple of (cb, current path, visited nodes)
             # these are our leaf nodes
@@ -698,6 +698,7 @@ def reduceGraph(graph, props=('up','down')):
                 break
 
 
+# TODO: Move into base exception file
 class PathForceQuitException(Exception):
     def __repr__(self):
         return "Path Generator forced to stop seeking a new path.  Possibly Timeout."
