@@ -5,14 +5,12 @@ import types
 import traceback
 
 from threading import Thread
-try:
-    from PyQt5.QtWidgets import *
-except:
-    from PyQt4.QtGui import *
+from PyQt5.QtWidgets import *
 
 from vqt.main import idlethread
 from vqt.basics import *
 
+
 @idlethread
 def scripterr(msg, info):
     msgbox = QMessageBox()
@@ -20,6 +18,7 @@ def scripterr(msg, info):
     msgbox.setInformativeText(info)
     msgbox.exec_()
 
+
 class ScriptThread(Thread):
 
     def __init__(self, cobj, locals):
@@ -34,6 +33,7 @@ class ScriptThread(Thread):
         except Exception as e:
             scripterr(str(e), traceback.format_exc())
 
+
 class VQPythonView(QWidget):
 
     def __init__(self, locals=None, parent=None):
@@ -49,15 +49,15 @@ class VQPythonView(QWidget):
         self._help_button = QPushButton('?', parent=self._botWidget)
         self._run_button = QPushButton('Run', parent=self._botWidget)
         self._run_button.clicked.connect(self._okClicked)
-        self._help_button.clicked.connect( self._helpClicked ) 
+        self._help_button.clicked.connect(self._helpClicked)
 
         self._help_text = None
 
-        hbox = HBox( None, self._help_button, self._run_button )
-        self._botWidget.setLayout( hbox )
+        hbox = HBox(None, self._help_button, self._run_button)
+        self._botWidget.setLayout(hbox)
 
-        vbox = VBox( self._textWidget, self._botWidget )
-        self.setLayout( vbox )
+        vbox = VBox(self._textWidget, self._botWidget)
+        self.setLayout(vbox)
 
         self.setWindowTitle('Python Interactive')
 
@@ -71,26 +71,25 @@ class VQPythonView(QWidget):
             exceptstr = traceback.format_exc()
             scripterr("Can't Compile", exceptstr)
 
-
     def _helpClicked(self):
         withhelp = []
-        for lname,lval in self._locals.items():
+        for lname, lval in self._locals.items():
             if type(lval) in (types.ModuleType, ):
                 continue
             doc = getattr(lval, '__doc__', '\nNo Documentation\n')
             if doc is None:
                 doc = '\nNo Documentation\n'
-            withhelp.append( (lname, doc) )
+            withhelp.append((lname, doc))
 
         withhelp.sort()
 
         txt = 'Objects/Functions in the namespace:\n'
-        for name,doc in withhelp:
-            txt += ( '====== %s\n' % name )
-            txt += ( '%s\n' % doc )
+        for name, doc in withhelp:
+            txt += ('====== %s\n' % name)
+            txt += ('%s\n' % doc)
 
         self._help_text = QTextEdit()
-        self._help_text.setReadOnly( True )
+        self._help_text.setReadOnly(True)
         self._help_text.setWindowTitle('Python Interactive Help')
-        self._help_text.setText( txt )
+        self._help_text.setText(txt)
         self._help_text.show()
